Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Tracker ¶
type Tracker struct {
// Plugin is the instance plugin to use
Plugin instance.Plugin
// Name is the name of the plugin
Name string
// contains filtered or unexported fields
}
Tracker implements the event spi -- just just calls the Describe to get a list of known instances, and report anything it hasn't seen before, or if anything that disappeared.
func NewTracker ¶
func NewTracker(name string, plugin instance.Plugin, tick <-chan time.Time, tags map[string]string) *Tracker
NewTracker returns an event plugin implementation that can generate events based on resources it trackers
Click to show internal directories.
Click to hide internal directories.