manager

package
v0.0.0-...-a355528 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 27, 2017 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Plugin

type Plugin struct {

	// DoLeaderLocation returns the location
	DoLeaderLocation func() (*url.URL, error)

	// DoIsLeader returns true if manager is leader
	DoIsLeader func() (bool, error)

	// DoEnforce enforces infrastructure state to match that of the specs
	DoEnforce func(specs []types.Spec) error

	// DoInspect returns the current state of the infrastructure
	DoInspect func() ([]types.Object, error)

	// DoTerminate destroys all resources associated with the specs
	DoTerminate func(specs []types.Spec) error
}

Plugin implements manager.Manager

func (*Plugin) Enforce

func (t *Plugin) Enforce(specs []types.Spec) error

Enforce enforces infrastructure state to match that of the specs

func (*Plugin) Inspect

func (t *Plugin) Inspect() ([]types.Object, error)

Inspect returns the current state of the infrastructure

func (*Plugin) IsLeader

func (t *Plugin) IsLeader() (bool, error)

IsLeader returns true if manager is leader

func (*Plugin) LeaderLocation

func (t *Plugin) LeaderLocation() (*url.URL, error)

LeaderLocation returns the location of the leader

func (*Plugin) Terminate

func (t *Plugin) Terminate(specs []types.Spec) error

Terminate destroys all resources associated with the specs

Jump to