Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Plugin ¶
type Plugin struct {
// DoList implements List via function
DoList func(path types.Path) (child []string, err error)
// DoGet implements Get via function
DoGet func(path types.Path) (value *types.Any, err error)
}
Plugin implements metadata.Plugin
type Updatable ¶
type Updatable struct {
Plugin
// DoChanges sends a batch of changes and gets in return a proposed view of configuration and a cas hash.
DoChanges func(changes []metadata.Change) (original, proposed *types.Any, cas string, err error)
// DoCommit asks the plugin to commit the proposed view with the cas. The cas is used for
// optimistic concurrency control.
DoCommit func(proposed *types.Any, cas string) error
}
Updatable implements metadata.Updatable
Click to show internal directories.
Click to hide internal directories.