Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultClientConfig ¶
func DefaultClientConfig() ssh.ClientConfig
DefaultClientConfig returns the default settings of the ssh client
Types ¶
type Tunnel ¶
type Tunnel struct {
// Local is the local endpoint for all clients
Local HostPort
// Server is the middle server listening on SSH port
Server HostPort
// Remote is the backend that's not accessible without going through the server endpoint
Remote HostPort
Config *ssh.ClientConfig
}
Tunnel is a forwarder of local ssh traffic to a remote endpoint
Click to show internal directories.
Click to hide internal directories.